summaryrefslogtreecommitdiffstats
path: root/korn/dockeditem.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/dockeditem.h')
-rw-r--r--korn/dockeditem.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/korn/dockeditem.h b/korn/dockeditem.h
index 4500d877..e5737608 100644
--- a/korn/dockeditem.h
+++ b/korn/dockeditem.h
@@ -40,10 +40,10 @@ class DockedItem : public BoxContainerItem
public:
/**
* This contructor gives all it parameters to its parents.
* @param parant The tqparent window
* @param name The name of the TQObject's parents.
*/
- DockedItem( TQWidget * tqparent = 0, const char * name = 0 );
+ DockedItem( TQWidget * parent = 0, const char * name = 0 );
/**
* Empty destructor; does nothing at the moment
*/
@@ -55,7 +55,7 @@ public:
virtual void showBox();
/**
* This functions reads the config. It used the tqparent
* version for the main things, but it is possible to
* add some configurations over here.
* @param config The KConfig-instance which contains the settings of this tray-item.
@@ -40,10 +40,10 @@ class DockedItem : public BoxContainerItem
/**
* This contructor gives all it parameters to its parents.
- * @param parant The tqparent window
+ * @param parant The parent window
* @param name The name of the TQObject's parents.
*/
@@ -55,7 +55,7 @@ public:
virtual void showBox();
/**
- * This functions reads the config. It used the tqparent
+ * This functions reads the config. It used the parent
* version for the main things, but it is possible to
* add some configurations over here.